/*
    ColorButton.cs - NRuler color button
    Copyright (C) 2008 siliconforks.com

    This file is part of NRuler.

    NRuler is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

using System;
using System.Drawing;
using System.Windows.Forms;

namespace SiliconForks.NRuler {
  public class ColorButton: Button {
    private Color optionColor;

    public Color OptionColor {
      get {
        return optionColor;
      }
      set {
        optionColor = value;
      }
    }

    public ColorButton() {
      SetStyle(ControlStyles.UserPaint, true);
    }

    protected override void OnPaint(PaintEventArgs e) {
      base.OnPaint(e);
      Brush brush = new SolidBrush(optionColor);
      Rectangle rectangle = new Rectangle(5, 5, Width - 10, Height - 10);
      e.Graphics.FillRectangle(brush, rectangle);
      brush.Dispose();
    }

    protected override void OnClick(EventArgs e) {
      ColorDialog colorDialog = new ColorDialog();
      colorDialog.Color = optionColor;
      if (colorDialog.ShowDialog() == DialogResult.OK) {
        optionColor = colorDialog.Color;
      }
    }
  }
}
