/*
    Help.cs - NRuler help form
    Copyright (C) 2007, 2008 siliconforks.com

    This file is part of NRuler.

    NRuler is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

using System;
using System.ComponentModel;
using System.Drawing;
using System.Reflection;
using System.Windows.Forms;

namespace SiliconForks.NRuler {
  public class Help: Form {
    public Help() {
      Text = "NRuler Help";
      Icon = new Icon(typeof(Ruler), "Icon");

      Label versionLabel = new Label();
      versionLabel.Location = new Point(8, 8);
      versionLabel.Size = new Size(300, 16);
      versionLabel.AutoSize = true;
      versionLabel.Text = "NRuler version " + Assembly.GetExecutingAssembly().GetName().Version + " (CLR version " + Environment.Version + ")";
      Controls.Add(versionLabel);

      LinkLabel linkLabel = new LinkLabel();
      linkLabel.Location = new Point(8, 8 + versionLabel.Height);
      linkLabel.Size = new Size(300, 16);
      linkLabel.AutoSize = true;
      string url = "http://siliconforks.com/nruler/";
      linkLabel.Text = url;
      linkLabel.Links.Add(0, url.Length, url);
      linkLabel.LinkClicked += new LinkLabelLinkClickedEventHandler(linkLabel_LinkClicked);
      linkLabel.TabIndex = 1;
      Controls.Add(linkLabel);

      string[] helpText = {
        "h           make horizontal",
        "v           make vertical",
        "o           make opaque",
        "t           always on top",
        "+, -        resize 1 px (Ctrl: 10 px)",
        "arrow keys  move 1 px (Ctrl: 10 px)",
        "F1, ?       this help",
        "q           quit",
      };
      int top = linkLabel.Top + linkLabel.Height;
      int maxWidth = Math.Max(versionLabel.Width, linkLabel.Width);
      int totalHeight = versionLabel.Height + linkLabel.Height;
      foreach (string h in helpText) {
        Label helpLabel = new Label();
        helpLabel.Location = new Point(8, top);
        helpLabel.Size = new Size(300, 16);
        helpLabel.AutoSize = true;
        helpLabel.Font = new Font(FontFamily.GenericMonospace, Font.Height, GraphicsUnit.Pixel);
        helpLabel.Text = h;
        Controls.Add(helpLabel);
        top += helpLabel.Height;
        if (maxWidth < helpLabel.Width) {
          maxWidth = helpLabel.Width;
        }
        totalHeight += helpLabel.Height;
      }

      Button button = new Button();
      button.Text = "Close";
      button.Anchor = AnchorStyles.Bottom | AnchorStyles.Right;
      button.Location = new Point(ClientSize.Width - 8 - button.Width, ClientSize.Height - 8 - button.Height);
      button.Click += new EventHandler(button_Click);
      button.TabIndex = 0;
      Controls.Add(button);

      ClientSize = new Size(8 + maxWidth + 8, 8 + totalHeight + button.Height + 8);
    }

    private void linkLabel_LinkClicked(object o, LinkLabelLinkClickedEventArgs e) {
      string target = e.Link.LinkData as string;
      // ???
      try {
        System.Diagnostics.Process.Start(target);
      }
      catch (SystemException) {
        MessageBox.Show("Unable to access URL.");
      }
    }

    private void button_Click(object o, EventArgs e) {
      Hide();
    }

    protected override void OnClosing(CancelEventArgs e) {
      base.OnClosing(e);
      e.Cancel = true;
      Hide();
    }
  }
}
