/*
    Options.cs - NRuler options
    Copyright (C) 2008 siliconforks.com

    This file is part of NRuler.

    NRuler is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

using System;
using System.Drawing;
using System.Globalization;
using System.IO;
using System.Windows.Forms;
using System.Xml;

namespace SiliconForks.NRuler {
  public class Options {
    private Color foreground = Color.Black;
    private Color background = Color.LightBlue;
    private Color grip = Color.Red;
    private float opacity = 0.65f;

    public Color Foreground {
      get {
        return foreground;
      }
      set {
        foreground = value;
      }
    }

    public Color Background {
      get {
        return background;
      }
      set {
        background = value;
      }
    }

    public Color Grip {
      get {
        return grip;
      }
      set {
        grip = value;
      }
    }

    public float Opacity {
      get {
        return opacity;
      }
      set {
        opacity = value;
      }
    }

    private static Color ParseRgb(string s) {
      int red = int.Parse(s.Substring(0, 2), NumberStyles.AllowHexSpecifier);
      int green = int.Parse(s.Substring(2, 2), NumberStyles.AllowHexSpecifier);
      int blue = int.Parse(s.Substring(4, 2), NumberStyles.AllowHexSpecifier);
      return Color.FromArgb(red, green, blue);
    }

    private static string Rgb(Color color) {
      return string.Format("{0:x2}{1:x2}{2:x2}", color.R, color.G, color.B);
    }

    public Options() {
      try {
        string directory = Application.UserAppDataPath;
        string file = Path.Combine(directory, "options.xml");
        if (! File.Exists(file)) {
          return;
        }
        XmlDocument document = new XmlDocument();
        document.Load(file);
        XmlNodeList options = document.GetElementsByTagName("option");
        foreach (XmlElement option in options) {
          string name = option.GetAttribute("name");
          string value = option.GetAttribute("value");
          if (name == "foreground") {
            foreground = ParseRgb(value);
          }
          else if (name == "background") {
            background = ParseRgb(value);
          }
          else if (name == "grip") {
            grip = ParseRgb(value);
          }
          else if (name == "opacity") {
            opacity = float.Parse(value);
          }
        }
      }
      catch (Exception e) {
        MessageBox.Show("Error: " + e.Message);
      }
    }

    public void Write() {
      try {
        string directory = Application.UserAppDataPath;

        // Mono 2.0 does not automatically create the directory
        Directory.CreateDirectory(directory);

        string file = Path.Combine(directory, "options.xml");
        using (StreamWriter writer = new StreamWriter(new FileStream(file, FileMode.Create))) {
          writer.WriteLine("<?xml version=\"1.0\"?>");
          writer.WriteLine("<options>");
          writer.WriteLine("  <option name='foreground' value='" + Rgb(foreground) + "'/>");
          writer.WriteLine("  <option name='background' value='" + Rgb(background) + "'/>");
          writer.WriteLine("  <option name='grip' value='" + Rgb(grip) + "'/>");
          writer.WriteLine("  <option name='opacity' value='" + opacity + "'/>");
          writer.WriteLine("</options>");
        }
      }
      catch (Exception e) {
        MessageBox.Show("Error: " + e.Message);
      }
    }
  }
}