/*
    OptionsForm.cs - NRuler options form
    Copyright (C) 2008 siliconforks.com

    This file is part of NRuler.

    NRuler is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

using System;
using System.Drawing;
using System.Windows.Forms;

namespace SiliconForks.NRuler {
  public class OptionsForm: Form {
    private Options options;

    private ColorButton foregroundButton;
    private ColorButton backgroundButton;
    private ColorButton gripButton;
    private NumericUpDown numericUpDown;

    public Options Options {
      get {
        return options;
      }
      set {
        options = value;
      }
    }

    public OptionsForm() {
      Text = "NRuler Options";
      FormBorderStyle = FormBorderStyle.FixedDialog;
      MinimizeBox = false;
      MaximizeBox = false;

      int fontHeight = Font.Height;

      GroupBox groupBox = new GroupBox();
      groupBox.FlatStyle = FlatStyle.System;
      groupBox.Text = "Colors";
      groupBox.Size = new Size(200, fontHeight * 9);
      Label label;
      label = new Label();
      label.Text = "Foreground:";
      label.Location = new Point(8, fontHeight * 2);
      groupBox.Controls.Add(label);
      label = new Label();
      label.Text = "Background:";
      label.Location = new Point(8, fontHeight * 4);
      groupBox.Controls.Add(label);
      label = new Label();
      label.Text = "Grip:";
      label.Location = new Point(8, fontHeight * 6);
      groupBox.Controls.Add(label);

      foregroundButton = new ColorButton();
      foregroundButton.Location = new Point(groupBox.Width - foregroundButton.Width - 8, fontHeight * 2 - (foregroundButton.Height - fontHeight) / 2);
      groupBox.Controls.Add(foregroundButton);

      backgroundButton = new ColorButton();
      backgroundButton.Location = new Point(groupBox.Width - backgroundButton.Width - 8, fontHeight * 4 - (backgroundButton.Height - fontHeight) / 2);
      groupBox.Controls.Add(backgroundButton);

      gripButton = new ColorButton();
      gripButton.Location = new Point(groupBox.Width - gripButton.Width - 8, fontHeight * 6 - (gripButton.Height - fontHeight) / 2);
      groupBox.Controls.Add(gripButton);

      label = new Label();
      label.Text = "Opacity:";
      numericUpDown = new NumericUpDown();
      numericUpDown.Minimum = 0.1M;
      numericUpDown.Maximum = 1;
      numericUpDown.DecimalPlaces = 2;
      numericUpDown.Increment = 0.01M;
      numericUpDown.TextAlign = HorizontalAlignment.Right;
      numericUpDown.ClientSize = new Size(60, numericUpDown.PreferredHeight);

      Button cancelButton = new Button();
      cancelButton.Text = "Cancel";
      CancelButton = cancelButton;
      Button okButton = new Button();
      okButton.Text = "OK";
      okButton.Click += new EventHandler(okButton_Click);
      AcceptButton = okButton;

      int clientWidth = 8 + groupBox.Width + 8;
      int clientHeight = 8 + groupBox.Height + 3 * fontHeight + cancelButton.Height + 8;
      ClientSize = new Size(clientWidth, clientHeight);

      groupBox.Location = new Point(8, 8);
      Controls.Add(groupBox);

      label.Location = new Point(8, groupBox.Top + groupBox.Height + fontHeight);
      numericUpDown.Location = new Point(clientWidth - numericUpDown.Width - 8, label.Top - (numericUpDown.Height - fontHeight) / 2);
      Controls.Add(label);
      Controls.Add(numericUpDown);

      cancelButton.Location = new Point(ClientSize.Width - cancelButton.Width - 8, ClientSize.Height - cancelButton.Height - 8);
      okButton.Location = new Point(cancelButton.Left - okButton.Width - 8, cancelButton.Top);
      // add the OK button first so it is first in tab order
      Controls.Add(okButton);
      Controls.Add(cancelButton);
    }

    private void okButton_Click(object sender, EventArgs eventArgs) {
      DialogResult = DialogResult.OK;
    }

    public void Get() {
      options.Foreground = foregroundButton.OptionColor;
      options.Background = backgroundButton.OptionColor;
      options.Grip = gripButton.OptionColor;
      options.Opacity = (float) numericUpDown.Value;
    }

    public void Set() {
      foregroundButton.OptionColor = options.Foreground;
      backgroundButton.OptionColor = options.Background;
      gripButton.OptionColor = options.Grip;
      numericUpDown.Value = (decimal) options.Opacity;
    }
  }
}